@@ -12,11 +12,10 @@
 #' @md
 #' @concept centralization
 #' @examples
-#' data("de_county")
+#' data('de_county')
 #' ds_abs_cent(de_county, c(pop_white, starts_with('pop_')))
 #' ds_abs_cent(de_county, c(pop_white, starts_with('pop_')), 'abs_cent')
-ds_abs_cent <- function(.data, .cols, .name){
-
+ds_abs_cent <- function(.data, .cols, .name) {
   if (!inherits(.data, 'sf')) {
     stop('`ds_abs_cent` requires `.data` to inherit sf for calculating areas.')
   }
@@ -33,37 +32,42 @@ ds_abs_cent <- function(.data, .cols, .name){
   .a <- calc_area(.data)
   .A <- sum(.a)
   .data$.dist <- calc_dist_centroid(.data)
-  .data <- .data %>% dplyr::arrange(.data$.dist)
+  .data <- .data |> dplyr::arrange(.data$.dist)
 
 
-  sub <- .data %>%
-    drop_sf() %>%
+  sub <- .data |>
+    drop_sf() |>
     dplyr::select(!!.cols)
 
   if (ncol(sub) <= 1) {
     stop('`.cols` refers to a single column')
   }
 
-  sub <- sub %>%
-    dplyr::rowwise() %>%
-    dplyr::mutate(.x = pick_n(1)) %>%
+  sub <- sub |>
+    dplyr::rowwise() |>
+    dplyr::mutate(.x = pick_n(1)) |>
     dplyr::ungroup()
 
   .X <- sum(sub[['.x']])
 
-  sub <- sub %>%
-    dplyr::mutate(.Xi = cumsum(.data$.x)/.X,
-                  .Ai = cumsum(.a)/.A,
-                  .Xi_min1 = dplyr::lag(.data$.Xi, default = 0),
-                  .Ai_min1 = dplyr::lag(.data$.Ai, default = 0))
+  sub <- sub |>
+    dplyr::mutate(
+      .Xi = cumsum(.data$.x) / .X,
+      .Ai = cumsum(.a) / .A,
+      .Xi_min1 = dplyr::lag(.data$.Xi, default = 0),
+      .Ai_min1 = dplyr::lag(.data$.Ai, default = 0)
+    )
 
-  out <- sub %>%
-    dplyr::mutate(!!.name := sum(.data$.Xi_min1*.data$.Ai) -
-                    sum(.data$.Xi*.data$.Ai_min1)) %>%
+  out <- sub |>
+    dplyr::mutate(
+      !!.name := sum(.data$.Xi_min1 * .data$.Ai) - sum(.data$.Xi * .data$.Ai_min1)
+    ) |>
     dplyr::pull(!!.name)
 
   if (ret_t) {
-    .data %>% dplyr::mutate(!!.name := out) %>% relocate_sf()
+    .data |>
+      dplyr::mutate(!!.name := out) |>
+      relocate_sf()
   } else {
     out
   }
