@@ -12,11 +12,10 @@
 #' @md
 #' @concept clustering
 #' @examples
-#' data("de_county")
+#' data('de_county')
 #' ds_abs_clust(de_county, c(pop_white, starts_with('pop_')))
 #' ds_abs_clust(de_county, c(pop_white, starts_with('pop_')), 'abs_clust')
-ds_abs_clust <- function(.data, .cols, .name){
-
+ds_abs_clust <- function(.data, .cols, .name) {
   if (!inherits(.data, 'sf')) {
     stop('`ds_abs_clust` requires `.data` to inherit sf for calculating areas.')
   }
@@ -34,39 +33,47 @@ ds_abs_clust <- function(.data, .cols, .name){
   .c <- calc_c(.data)
   .C <- sum(.c)
 
-  sub <- .data %>%
-    drop_sf() %>%
+  sub <- .data |>
+    drop_sf() |>
     dplyr::select(!!.cols)
 
   if (ncol(sub) <= 1) {
     stop('`.cols` refers to a single column')
   }
 
-  sub <- sub %>%
-    dplyr::rowwise() %>%
-    dplyr::mutate(.total = sum(dplyr::c_across(everything())),
-                  .x = pick_n(1)) %>%
+  sub <- sub |>
+    dplyr::rowwise() |>
+    dplyr::mutate(
+      .total = sum(dplyr::c_across(everything())),
+      .x = pick_n(1)
+    ) |>
     dplyr::ungroup()
 
   .X <- sum(sub$.x)
   .N <- nrow(sub)
   .N2 <- .N^2
 
-  .xmat <- matrix(data = rep(sub %>% dplyr::pull(.data$.x), .N),
-                  nrow = .N, ncol = .N, byrow = TRUE)
+  .xmat <- matrix(
+    data = rep(sub |> dplyr::pull(.data$.x), .N),
+    nrow = .N, ncol = .N, byrow = TRUE
+  )
   sub$.xvec <- rowSums(.c * .xmat)
-  .tmat <- matrix(data = rep(sub %>% dplyr::pull(.data$.total), .N),
-                  nrow = .N, ncol = .N, byrow = TRUE)
+  .tmat <- matrix(
+    data = rep(sub |> dplyr::pull(.data$.total), .N),
+    nrow = .N, ncol = .N, byrow = TRUE
+  )
   sub$.tvec <- rowSums(.c * .tmat)
 
 
-  out <- sub %>%
-    dplyr::mutate(!!.name := (sum((.data$.x/.X * .data$.xvec) ) - (.X/.N2*.C))/
-                    (sum((.data$.x/.X ) * .data$.tvec) - (.X/.N2*.C)) ) %>%
+  out <- sub |>
+    dplyr::mutate(!!.name := (sum((.data$.x / .X * .data$.xvec)) - (.X / .N2 * .C)) /
+      (sum((.data$.x / .X) * .data$.tvec) - (.X / .N2 * .C))) |>
     dplyr::pull(!!.name)
 
   if (ret_t) {
-    .data %>% dplyr::mutate(!!.name := out) %>% relocate_sf()
+    .data |>
+      dplyr::mutate(!!.name := out) |>
+      relocate_sf()
   } else {
     out
   }
