@@ -26,30 +26,32 @@ ds_isolation <- function(.data, .cols, .name, .comp = FALSE) {
     ret_t <- TRUE
   }
 
-  sub <- .data %>%
-    drop_sf() %>%
+  sub <- .data |>
+    drop_sf() |>
     dplyr::select(!!.cols)
 
   if (ncol(sub) <= 1) {
     stop('.cols refers to a single column')
   }
 
-  sub <- sub %>%
-    dplyr::rowwise() %>%
-    dplyr::mutate(.total = sum(dplyr::c_across(everything())),
-                  .x = pick_n(1)) %>%
+  sub <- sub |>
+    dplyr::rowwise() |>
+    dplyr::mutate(
+      .total = sum(dplyr::c_across(everything())),
+      .x = pick_n(1)
+    ) |>
     dplyr::ungroup()
 
   .X <- sum(sub$.x)
 
-  out <- sub %>%
-    rowwise_if(.comp) %>%
-    dplyr::mutate(!!.name := sum((.data$.x/.X)*(.data$.x/.data$.total))) %>%
+  out <- sub |>
+    rowwise_if(.comp) |>
+    dplyr::mutate(!!.name := sum((.data$.x / .X) * (.data$.x / .data$.total))) |>
     dplyr::pull(!!.name)
 
   if (ret_t) {
-    .data %>%
-      dplyr::mutate(!!.name := out) %>%
+    .data |>
+      dplyr::mutate(!!.name := out) |>
       relocate_sf()
   } else {
     out
