@@ -11,10 +11,10 @@
 #' @md
 #' @concept div
 #' @examples
-#' data("de_county")
+#' data('de_county')
 #' ds_shannon(de_county, starts_with('pop_'))
 #' ds_shannon(de_county, starts_with('pop_'), 'shannon')
-ds_shannon <- function(.data, .cols, .name){
+ds_shannon <- function(.data, .cols, .name) {
   .cols <- rlang::enquo(.cols)
 
   if (missing(.name)) {
@@ -24,16 +24,18 @@ ds_shannon <- function(.data, .cols, .name){
     ret_t <- TRUE
   }
 
-  out <- .data %>%
-    drop_sf() %>%
-    dplyr::rowwise() %>%
-    dplyr::mutate(.total = sum(dplyr::c_across(!!.cols))) %>%
-    dplyr::mutate(!!.name := -1 * sum( (dplyr::select(dplyr::across(everything()), !!.cols)/.data$.total) *
-                                           log((dplyr::select(dplyr::across(everything()), !!.cols)/.data$.total))) ) %>%
+  out <- .data |>
+    drop_sf() |>
+    dplyr::rowwise() |>
+    dplyr::mutate(.total = sum(dplyr::c_across(!!.cols))) |>
+    dplyr::mutate(!!.name := -1 * sum((dplyr::select(dplyr::across(everything()), !!.cols) / .data$.total) *
+      log((dplyr::select(dplyr::across(everything()), !!.cols) / .data$.total)))) |>
     dplyr::pull(!!.name)
 
   if (ret_t) {
-    .data %>% dplyr::mutate(!!.name := out) %>% relocate_sf()
+    .data |>
+      dplyr::mutate(!!.name := out) |>
+      relocate_sf()
   } else {
     out
   }
