@@ -1,4 +1,4 @@
-test_that("abs_conc works", {
+test_that('abs_conc works', {
   skip_on_os('solaris')
   skip_if_not(sf::sf_use_s2())
   .act <- ds_abs_conc(de_county, c(pop_black, starts_with('pop_')))
@@ -6,7 +6,7 @@ test_that("abs_conc works", {
   expect_equal(.act, .exp, tolerance = 1e-6)
 })
 
-test_that("abs_conc .name works", {
+test_that('abs_conc .name works', {
   .act <- ds_abs_conc(de_county, c(pop_black, starts_with('pop_')), .name = 'special_name')
   expect_true('special_name' %in% names(.act))
 })
