@@ -1,16 +1,16 @@
-test_that("entropy works", {
+test_that('entropy works', {
   .act <- ds_entropy(de_county, starts_with('pop_'))
-  .exp <- c(0.638090971561592, 0.638090971561592, 0.638090971561592)
+  .exp <- c(0.0111514471973371, 0.0111514471973371, 0.0111514471973371)
   expect_equal(.act, .exp, tolerance = 1e-6)
 })
 
-test_that("entropy .name works", {
+test_that('entropy .name works', {
   .act <- ds_entropy(de_county, starts_with('pop_'), .name = 'special_name')
   expect_true('special_name' %in% names(.act))
 })
 
-test_that("entropy .comp works", {
+test_that('entropy .comp works', {
   .act <- ds_entropy(de_county, starts_with('pop_'), .comp = TRUE)
-  .exp <- c(0.116761244988572, 0.399314289368122, 0.122015437204899)
+  .exp <- c(-0.000185325986678492, -0.0191300983383268, 0.0304668715223424)
   expect_equal(.act, .exp, tolerance = 1e-6)
 })
