@@ -1,3 +1,3 @@
-test_that("perplexity copied", {
+test_that('perplexity copied', {
   expect_identical(ds_perplexity, ds_diversity)
 })
