@@ -1,3 +1,3 @@
-test_that("simpson copied", {
+test_that('simpson copied', {
   expect_identical(ds_simpson, ds_hhi)
 })
